# METER
## (Multi-state Estimates for Time-to-Event Research)
An implementation of multi-state life table analysis for projects and research involving longevity and markov chain models. Useful for analysis of inhomogenous discrete-time acyclic markov chain processes. 

## References

(1) Bootstrapping procedure based on methods described by Abdullah Al Mamun at the University of Groningen.
 
Link: https://www.rug.nl/research/portal/files/10377353/thesis.pdf

(2) Code modelled partially on the MState R package and all corresponding functions are checked against it.

Link: https://cran.r-project.org/web/packages/mstate/mstate.pdf 